@@ -3,14 +3,14 @@
 // SPDX-License-Identifier: GPL-3.0-only
 
 #include "abstractaccount.h"
-#include "identity.h"
 
 #include "accountmanager.h"
-#include "post.h"
-#include "relationship.h"
 #include "messagefiltercontainer.h"
+#include "relationship.h"
 #include "tokodon_debug.h"
 #include <KLocalizedString>
+#include <QFile>
+#include <QHttpMultiPart>
 #include <QNetworkReply>
 #include <QUrlQuery>
 
@@ -139,9 +139,7 @@ bool AbstractAccount::identityCached(const QString &acct) const
 
 QUrlQuery AbstractAccount::buildOAuthQuery() const
 {
-    QUrlQuery q;
-    q.addQueryItem("client_id", m_client_id);
-    return q;
+    return QUrlQuery{{"client_id", m_client_id}};
 }
 
 QUrl AbstractAccount::getAuthorizeUrl() const
@@ -360,16 +358,6 @@ QUrl AbstractAccount::streamingUrl(const QString &stream)
     return QUrl(url);
 }
 
-void AbstractAccount::handleUpdate(const QJsonDocument &doc, const QString &target)
-{
-    QList<Post *> posts;
-    const auto obj = doc.object();
-    const auto p = new Post(this, obj, this);
-    posts.push_back(p);
-
-    Q_EMIT fetchedTimeline(target, posts);
-}
-
 void AbstractAccount::handleNotification(const QJsonDocument &doc)
 {
     const auto obj = doc.object();
