@@ -120,6 +120,7 @@ public:
 
     virtual void post(const QUrl &url, QHttpMultiPart *message, bool authenticated, QObject *parent, std::function<void(QNetworkReply *)> callback) = 0;
     virtual void put(const QUrl &url, const QJsonDocument &doc, bool authenticated, QObject *parent, std::function<void(QNetworkReply *)> callback) = 0;
+    virtual void patch(const QUrl &url, QHttpMultiPart *multiPart, bool authenticated, QObject *parent, std::function<void(QNetworkReply *)>) = 0;
 
     /// Upload a file
     virtual void upload(Post *post, QFile *file, const QString &filename) = 0;
@@ -183,6 +184,19 @@ public:
         Note,
     };
 
+    enum StreamingEventType {
+        UpdateEvent, //< A new Status has appeared.
+        DeleteEvent, ///< A status has been deleted.
+        NotificationEvent, ///< A new notification has appeared.
+        FiltersChangedEvent, ///< Keyword filters have been changed.
+        ConversationEvent, ///< A direct conversation has been updated.
+        AnnouncementEvent, //< An announcement has been published.
+        AnnouncementRedactedEvent, //< An announcement has received an emoji reaction.
+        AnnouncementDeletedEvent, //< An announcement has been deleted.
+        StatusUpdatedEvent, ///< A Status has been edited.
+        EncryptedMessageChangedEvent, ///< An encrypted message has been received.
+    };
+
 Q_SIGNALS:
     void authenticated();
     void registered();
@@ -196,6 +210,7 @@ Q_SIGNALS:
     void notification(std::shared_ptr<Notification> n);
     void followRequestBlocked();
     void errorOccured(const QString &errorMessage);
+    void streamingEvent(AbstractAccount::StreamingEventType eventType, const QByteArray &payload);
 
 protected:
     QString m_name;
