@@ -42,18 +42,23 @@ public:
         UrlRole,
         CardRole,
         TypeRole,
+        PollRole,
+        VisibilityRole,
+        SelectedRole,
         ExtraRole, ///< for sub-classes to extend the roles
     };
 
     AbstractTimelineModel(QObject *parent = nullptr);
     QHash<int, QByteArray> roleNames() const override;
+    QVariant postData(Post *post, int role) const;
 
     bool loading() const;
+    void setLoading(bool loading);
 
 Q_SIGNALS:
     void loadingChanged();
 
 protected:
     AbstractAccount *m_account = nullptr;
-    bool m_loading = true;
+    bool m_loading = false;
 };
