@@ -4,9 +4,9 @@
 
 #include "accountmanager.h"
 #include "account.h"
-#include "networkaccessmanagerfactory.h"
 #include "accountmodel.h"
 #include "config.h"
+#include "networkaccessmanagerfactory.h"
 
 AccountManager::AccountManager(QObject *parent)
     : QAbstractListModel(parent)
@@ -162,7 +162,7 @@ AbstractAccount *AccountManager::selectedAccount() const
 
 QVariant AccountManager::selectedAccountModel()
 {
-    return QVariant::fromValue<QAbstractListModel *>(new AccountModel(this, m_selected_account->identity().id(), m_selected_account->identity().account()));
+    return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_selected_account->identity().id(), m_selected_account->identity().account()));
 }
 
 int AccountManager::selectedIndex() const
