@@ -8,40 +8,39 @@
 #include <QCoreApplication>
 #include <QUrlQuery>
 
-AccountModel::AccountModel(AccountManager *manager, qint64 id, const QString &acct, QObject *parent)
+AccountModel::AccountModel(qint64 id, const QString &acct, QObject *parent)
     : TimelineModel(parent)
     , m_identity(nullptr)
     , m_id(id)
 {
-    setName(acct);
-    setAccountManager(manager);
+    init();
 
     connect(this, &AccountModel::identityChanged, this, &TimelineModel::nameChanged);
 
     if (!m_account->identityCached(acct)) {
         QUrl uriAccount(m_account->instanceUri());
-        uriAccount.setPath(QString("/api/v1/accounts/%1").arg(id));
+        uriAccount.setPath(QStringLiteral("/api/v1/accounts/%1").arg(id));
 
-        manager->selectedAccount()->get(uriAccount, true, this, [this, manager, &acct](QNetworkReply *reply) {
+        m_account->get(uriAccount, true, this, [this, acct](QNetworkReply *reply) {
             const auto data = reply->readAll();
             const auto doc = QJsonDocument::fromJson(data);
 
-            m_identity = manager->selectedAccount()->identityLookup(acct, doc.object());
+            m_identity = m_account->identityLookup(acct, doc.object());
             Q_EMIT identityChanged();
             updateRelationships();
         });
     } else {
         const QJsonObject empty;
         m_identity = m_account->identityLookup(acct, empty);
-        Q_EMIT identityChanged();
         updateRelationships();
     }
 }
 
 bool AccountModel::isSelf() const
 {
-    if(m_identity == nullptr)
+    if (m_identity == nullptr) {
         return false;
+    }
 
     return m_account->identity().id() == m_identity->id();
 }
@@ -57,9 +56,8 @@ QString AccountModel::displayName() const
 
 void AccountModel::fillTimeline(const QString &fromId)
 {
-    m_fetching = true;
+    setLoading(true);
 
-    auto thread = std::make_shared<QList<Post *>>();
     // Fetch pinned posts if we are starting from the top
     const auto fetchPinned = fromId.isNull();
     const auto excludeReplies = true;
@@ -79,47 +77,49 @@ void AccountModel::fillTimeline(const QString &fromId)
     auto uriPinned = m_account->apiUrl(QString("/api/v1/accounts/%1/statuses").arg(m_id));
     uriPinned.setQuery(QUrlQuery{{"pinned", "true"}});
 
-    auto onFetchPinned = [=](QNetworkReply *reply) {
+    const auto account = m_account;
+    const auto id = m_id;
+
+    auto onFetchPinned = [this, id, account](QNetworkReply *reply) {
+        if (m_account != account || m_id != id) {
+            setLoading(false);
+            return;
+        }
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
-
         if (!doc.isArray()) {
+            setLoading(false);
+            return;
+        }
+        const auto array = doc.array();
+        if (array.isEmpty()) {
+            setLoading(false);
             return;
         }
 
-        int i = 0;
-        const auto array = doc.array();
-        for (const auto &value : array) {
-            const QJsonObject obj = value.toObject();
-
-            auto p = new Post(m_account, obj, this);
-            thread->insert(i, p);
-            i++;
-        }
-
-        fetchedTimeline(m_account, m_timelineName, *thread);
+        QList<Post *> posts;
+        std::transform(array.cbegin(), array.cend(), std::back_inserter(posts), [this](const QJsonValue &value) {
+            auto post = new Post(m_account, value.toObject(), this);
+            post->m_pinned = true;
+            return post;
+        });
+        beginInsertRows({}, 0, posts.size() - 1);
+        m_timeline = posts + m_timeline;
+        endInsertRows();
+        setLoading(false);
     };
 
-    auto onFetchAccount = [=](QNetworkReply *reply) {
-        const auto data = reply->readAll();
-        const auto doc = QJsonDocument::fromJson(data);
-
-        if (!doc.isArray()) {
+    auto onFetchAccount = [account, id, fetchPinned, uriPinned, onFetchPinned, this](QNetworkReply *reply) {
+        if (m_account != account || m_id != id) {
+            setLoading(false);
             return;
         }
 
-        const auto array = doc.array();
-        for (const auto &value : array) {
-            const QJsonObject obj = value.toObject();
-
-            auto p = new Post(m_account, obj, this);
-            thread->push_back(p);
-        }
-
+        fetchedTimeline(reply->readAll());
         if (fetchPinned) {
             m_account->get(uriPinned, true, this, onFetchPinned);
         } else {
-            fetchedTimeline(m_account, m_timelineName, *thread);
+            setLoading(false);
         }
     };
 
@@ -138,19 +138,19 @@ AbstractAccount *AccountModel::account() const
 
 void AccountModel::updateRelationships()
 {
-    if (m_account->identity().id() != m_identity->id()) {
+    if (m_account->identity().id() == m_identity->id()) {
         return;
     }
 
     // Fetch relationship. Don't cache this; it's lightweight.
     QUrl uriRelationship(m_account->instanceUri());
     uriRelationship.setPath(QStringLiteral("/api/v1/accounts/relationships"));
-    uriRelationship.setQuery(QUrlQuery{{QStringLiteral("id[]"), QString::number(m_identity->id())}});
+    uriRelationship.setQuery(QUrlQuery{{QStringLiteral("id[]"), QString::number(m_identity->id())},});
 
     m_account->get(uriRelationship, true, this, [this](QNetworkReply *reply) {
         const auto doc = QJsonDocument::fromJson(reply->readAll());
         if (!doc.isArray()) {
-            qDebug() << "Data returned from Relationship network request is not an array"
+            qWarning() << "Data returned from Relationship network request is not an array"
                      << "data: " << doc;
             return;
         }
