@@ -5,7 +5,6 @@
 #include "abstractaccount.h"
 #include "relationship.h"
 #include <QJsonObject>
-#include <qjsonarray.h>
 
 QString Identity::displayName() const
 {
@@ -104,6 +103,7 @@ void Identity::fromSourceData(const QJsonObject &doc)
     m_followingCount = doc["following_count"].toInt();
     m_statusesCount = doc["statuses_count"].toInt();
     m_fields = doc["fields"].toArray();
+    m_url = doc["url"].toString();
 
     // When the user data is ourselves, we get source.privacy
     // with the default post privacy setting for the user. all others
@@ -111,21 +111,20 @@ void Identity::fromSourceData(const QJsonObject &doc)
     QJsonObject source = doc["source"].toObject();
     m_visibility = source["privacy"].toString();
 
-
     if (m_account == m_parent->identity().m_account) {
         m_parent->setDirtyIdentity();
     }
 
-    m_displayNameHtml = m_displayName
-        .replace(QLatin1Char('<'), QStringLiteral("&lt;"))
-        .replace(QLatin1Char('>'), QStringLiteral("&gt;"));
+    m_displayNameHtml = m_displayName.replace(QLatin1Char('<'), QStringLiteral("&lt;")).replace(QLatin1Char('>'), QStringLiteral("&gt;"));
 
     const auto emojis = doc["emojis"].toArray();
 
     for (const auto &emoji : emojis) {
         const auto emojiObj = emoji.toObject();
-        m_displayNameHtml = m_displayNameHtml.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'), "<img height=\"16\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
-        m_bio = m_bio.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'), "<img height=\"16\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
+        m_displayNameHtml = m_displayNameHtml.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'),
+                                                      "<img height=\"16\" align=\"middle\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
+        m_bio = m_bio.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'),
+                              "<img height=\"16\" width=\"16\" align=\"middle\" src=\"" + emojiObj["static_url"].toString() + "\">");
     }
 
     Q_EMIT identityUpdated();
@@ -140,3 +139,8 @@ QString Identity::displayNameHtml() const
 {
     return !m_displayNameHtml.isEmpty() ? m_displayNameHtml : m_username;
 }
+
+QUrl Identity::url() const
+{
+    return m_url;
+}
