@@ -36,10 +36,17 @@
 #include "blurhashimageprovider.h"
 #include "clipboard.h"
 #include "config.h"
-#include "networkaccessmanagerfactory.h"
-#include "notificationmodel.h"
-#include "post.h"
+#include "conversationmodel.h"
 #include "filehelper.h"
+#include "maintimelinemodel.h"
+#include "networkaccessmanagerfactory.h"
+#include "networkcontroller.h"
+#include "notificationmodel.h"
+#include "poll.h"
+#include "post.h"
+#include "profileeditor.h"
+#include "searchmodel.h"
+#include "tagsmodel.h"
 #include "timelinemodel.h"
 
 #ifdef Q_OS_ANDROID
@@ -84,7 +91,7 @@ int main(int argc, char *argv[])
                      QStringLiteral(TOKODON_VERSION_STRING),
                      i18n("Mastodon client"),
                      KAboutLicense::GPL_V3,
-                     i18n("© 2021 Carl Schwan, 2021 KDE Community"));
+                     i18n("© 2021-2023 Carl Schwan, 2021-2023 KDE Community"));
     about.addAuthor(i18n("Carl Schwan"), i18n("Maintainer"), QStringLiteral("carl@carlschwan.eu"));
     about.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     about.setOrganizationDomain("kde.org");
@@ -99,8 +106,13 @@ int main(int argc, char *argv[])
     auto config = Config::self();
 
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Config", config);
+    qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Controller", &NetworkController::instance());
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "AccountManager", &AccountManager::instance());
-    qmlRegisterType<TimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
+    qmlRegisterType<MainTimelineModel>("org.kde.kmasto", 1, 0, "TimelineModel");
+    qmlRegisterType<SearchModel>("org.kde.kmasto", 1, 0, "SearchModel");
+    qmlRegisterType<ConversationModel>("org.kde.kmasto", 1, 0, "ConversationModel");
+    qmlRegisterType<TagsModel>("org.kde.kmasto", 1, 0, "TagsModel");
+    qmlRegisterType<ProfileEditorBackend>("org.kde.kmasto", 1, 0, "ProfileEditorBackend");
     qmlRegisterType<NotificationModel>("org.kde.kmasto", 1, 0, "NotificationModel");
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "Clipboard", new Clipboard);
     qmlRegisterSingletonInstance("org.kde.kmasto", 1, 0, "FileHelper", new FileHelper);
@@ -111,6 +123,7 @@ int main(int argc, char *argv[])
     qRegisterMetaType<Account *>("Account*");
     qRegisterMetaType<AbstractAccount *>("AbstractAccount*");
     qRegisterMetaType<Identity *>("Identity*");
+    qRegisterMetaType<Poll *>("Poll*");
     qRegisterMetaType<Relationship *>("Relationship*");
     qmlRegisterUncreatableType<Post>("org.kde.kmasto", 1, 0, "Post", "ENUM");
     qmlRegisterUncreatableType<Notification>("org.kde.kmasto", 1, 0, "Notification", "ENUM");
