@@ -12,9 +12,10 @@
 NotificationModel::NotificationModel(QObject *parent)
     : AbstractTimelineModel(parent)
 {
-    m_account = AccountManager::instance().selectedAccount();
+    m_manager = &AccountManager::instance();
+    m_account = m_manager->selectedAccount();
 
-    QObject::connect(&AccountManager::instance(), &AccountManager::invalidated, this, [=](AbstractAccount *account) {
+    connect(m_manager, &AccountManager::invalidated, this, [=](AbstractAccount *account) {
         if (m_account == account) {
             qDebug() << "Invalidating account" << account;
 
@@ -22,7 +23,19 @@ NotificationModel::NotificationModel(QObject *parent)
             m_notifications.clear();
             endResetModel();
             m_next = QString();
-            m_fetching = false;
+            setLoading(false);
+        }
+    });
+
+    connect(m_manager, &AccountManager::accountSelected, this, [=](AbstractAccount *account) {
+        if (m_account != account) {
+            m_account = account;
+
+            beginResetModel();
+            m_notifications.clear();
+            endResetModel();
+
+            fillTimeline();
         }
     });
 
@@ -31,11 +44,11 @@ NotificationModel::NotificationModel(QObject *parent)
         m_notifications.clear();
         endResetModel();
         m_next = QString();
-        m_fetching = false;
+        setLoading(false);
         fillTimeline();
     });
 
-    m_fetching = false;
+    setLoading(false);
     fillTimeline();
 }
 
@@ -60,10 +73,10 @@ void NotificationModel::fillTimeline(const QUrl &next)
         return;
     }
 
-    if (m_fetching) {
+    if (m_loading) {
         return;
     }
-    m_fetching = true;
+    setLoading(true);
     QUrl uri;
     if (next.isEmpty()) {
         uri = QUrl::fromUserInput(m_account->instanceUri());
@@ -81,10 +94,7 @@ void NotificationModel::fillTimeline(const QUrl &next)
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
-        if (m_loading) {
-            m_loading = false;
-            Q_EMIT loadingChanged();
-        }
+        setLoading(false);
 
         if (!doc.isArray()) {
             m_account->errorOccured(i18n("Error occurred when fetching the latest notification."));
@@ -102,7 +112,14 @@ void NotificationModel::fillTimeline(const QUrl &next)
             const auto notification = std::make_shared<Notification>(m_account, obj, this);
             notifications.push_back(notification);
         }
-        fetchedNotifications(notifications);
+
+        if (notifications.isEmpty()) {
+            return;
+        }
+
+        beginInsertRows({}, m_notifications.count(), m_notifications.count() + notifications.count() - 1);
+        m_notifications.append(notifications);
+        endInsertRows();
     });
 }
 
@@ -110,7 +127,7 @@ void NotificationModel::fetchMore(const QModelIndex &parent)
 {
     Q_UNUSED(parent);
 
-    if (m_notifications.isEmpty() || !m_next.isValid() || m_fetching) {
+    if (m_notifications.isEmpty() || !m_next.isValid() || m_loading) {
         return;
     }
 
@@ -122,20 +139,7 @@ bool NotificationModel::canFetchMore(const QModelIndex &parent) const
     Q_UNUSED(parent);
 
     // Todo detect when there is nothing left
-    return !m_fetching;
-}
-
-void NotificationModel::fetchedNotifications(QList<std::shared_ptr<Notification>> notifications)
-{
-    m_fetching = false;
-
-    if (notifications.isEmpty()) {
-        return;
-    }
-
-    beginInsertRows({}, m_notifications.count(), m_notifications.count() + notifications.count() - 1);
-    m_notifications.append(notifications);
-    endInsertRows();
+    return !loading();
 }
 
 int NotificationModel::rowCount(const QModelIndex &parent) const
@@ -145,13 +149,6 @@ int NotificationModel::rowCount(const QModelIndex &parent) const
     return m_notifications.size();
 }
 
-// this is even more extremely cursed
-std::shared_ptr<Notification> NotificationModel::internalData(const QModelIndex &index) const
-{
-    int row = index.row();
-    return m_notifications[row];
-}
-
 QHash<int, QByteArray> NotificationModel::roleNames() const
 {
     auto roles = AbstractTimelineModel::roleNames();
@@ -169,20 +166,8 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
     auto post = notification->post();
 
     switch (role) {
-    case IdRole:
-        return post->m_post_id;
-    case MentionsRole:
-        return post->mentions();
     case TypeRole:
         return notification->type();
-    case Qt::DisplayRole:
-        return post->m_content;
-    case AvatarRole:
-        return post->authorIdentity()->avatarUrl();
-    case AuthorIdRole:
-        return post->authorIdentity()->account();
-    case PublishedAtRole:
-        return post->m_published_at;
     case WasRebloggedRole:
         return post->m_repeat || notification->type() == Notification::Repeat;
     case RebloggedDisplayNameRole:
@@ -193,58 +178,16 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
             return notification->identity()->displayName();
         }
         return {};
-    case AuthorDisplayNameRole:
-        return post->authorIdentity()->displayNameHtml();
-    case RebloggedIdRole:
-        if (post->repeatIdentity()) {
-            return post->repeatIdentity()->account();
-        }
-        if (notification->type() == Notification::Repeat) {
-            return notification->identity()->account();
-        }
-        return {};
-    case RebloggedRole:
-        return post->m_isRepeated;
-    case ReblogsCountRole:
-        return post->m_repeatedCount;
-    case FavoritedRole:
-        return post->m_isFavorite;
-    case PinnedRole:
-        return post->m_pinned;
-    case SensitiveRole:
-        return post->m_isSensitive;
-    case SpoilerTextRole:
-        return post->m_subject;
-    case AttachmentsRole:
-        return QVariant::fromValue<QList<Attachment *>>(post->m_attachments);
-    case ThreadModelRole:
-        return QVariant::fromValue<QAbstractListModel *>(new ThreadModel(m_manager, post->m_post_id));
-    case CardRole:
-        if (post->card().has_value()) {
-            return QVariant::fromValue<Card>(*post->card());
-        }
-        return false;
-    case AccountModelRole:
-        return QVariant::fromValue<QAbstractListModel *>(new AccountModel(m_manager, post->authorIdentity()->id(), post->authorIdentity()->account()));
-    case RelativeTimeRole: {
-        const auto current = QDateTime::currentDateTime();
-        auto secsTo = post->m_published_at.secsTo(current);
-        if (secsTo < 60 * 60) {
-            const auto hours = post->m_published_at.time().hour();
-            const auto minutes = post->m_published_at.time().minute();
-            return i18nc("hour:minute",
-                         "%1:%2",
-                         hours < 10 ? QChar('0') + QString::number(hours) : QString::number(hours),
-                         minutes < 10 ? QChar('0') + QString::number(minutes) : QString::number(minutes));
-        } else if (secsTo < 60 * 60 * 24) {
-            return i18n("%1h", qCeil(secsTo / (60 * 60)));
-        } else if (secsTo < 60 * 60 * 24 * 7) {
-            return i18n("%1d", qCeil(secsTo / (60 * 60 * 24)));
-        }
-        return QLocale::system().toString(post->m_published_at.date(), QLocale::ShortFormat);
-    }
     case NotificationActorIdentityRole:
         return QVariant::fromValue(notification->identity().get());
+    case AccountModelRole:
+        if (notification->type() == Notification::Follow || notification->type() == Notification::FollowRequest) {
+            return QVariant::fromValue<QAbstractListModel *>(new AccountModel(notification->identity()->id(), notification->identity()->account()));
+        } else {
+            return QVariant::fromValue<QAbstractListModel *>(new AccountModel(post->authorIdentity()->id(), post->authorIdentity()->account()));
+        }
+    default:
+        return postData(post, role);
     }
 
     return {};
@@ -258,14 +201,6 @@ void NotificationModel::actionReply(const QModelIndex &index)
     Q_EMIT wantReply(m_account, p, index);
 }
 
-void NotificationModel::actionMenu(const QModelIndex &index)
-{
-    int row = index.row();
-    auto p = m_notifications[row]->post();
-
-    Q_EMIT wantMenu(m_account, p, index);
-}
-
 void NotificationModel::actionFavorite(const QModelIndex &index)
 {
     int row = index.row();
