@@ -34,13 +34,11 @@ public Q_SLOTS:
     void actionReply(const QModelIndex &index);
     void actionFavorite(const QModelIndex &index);
     void actionRepeat(const QModelIndex &index);
-    void actionMenu(const QModelIndex &index);
     void actionVis(const QModelIndex &index);
 
 Q_SIGNALS:
     void excludeTypesChanged();
     void wantReply(AbstractAccount *account, Post *post, const QModelIndex &index);
-    void wantMenu(AbstractAccount *account, Post *post, const QModelIndex &index);
 
 protected:
     void fetchMore(const QModelIndex &parent) override;
@@ -51,10 +49,6 @@ protected:
     AbstractAccount *m_account = nullptr;
 
     QList<std::shared_ptr<Notification>> m_notifications;
-    bool m_fetching;
     QStringList m_excludeTypes;
     QUrl m_next;
-
-public Q_SLOTS:
-    void fetchedNotifications(QList<std::shared_ptr<Notification>> notifications);
 };
