@@ -8,6 +8,7 @@
 #include <qurl.h>
 
 #include "account.h"
+#include "poll.h"
 #include "post.h"
 
 static QMap<QString, Attachment::AttachmentType> stringToAttachmentType = {
@@ -29,6 +30,8 @@ Attachment::Attachment(Post *parent, const QJsonObject &obj)
     m_preview_url = obj["preview_url"].toString();
     m_description = obj["description"].toString();
     m_blurhash = obj["blurhash"].toString();
+    m_originalHeight = obj["meta"].toObject()["original"].toObject()["height"].toInt();
+    m_originalWidth = obj["meta"].toObject()["original"].toObject()["width"].toInt();
 
     // determine type if we can
     auto type = obj["type"].toString();
@@ -100,7 +103,18 @@ Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
 
     for (const auto &emoji : emojis) {
         const auto emojiObj = emoji.toObject();
-        m_content = m_content.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'), "<img height=\"16\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
+        m_content = m_content.replace(QLatin1Char(':') + emojiObj["shortcode"].toString() + QLatin1Char(':'),
+                                      "<img height=\"16\" align=\"middle\" width=\"16\" src=\"" + emojiObj["static_url"].toString() + "\">");
+    }
+
+    const auto tags = obj["tags"].toArray();
+    const QString baseUrl = authorIdentity()->url().toDisplayString(QUrl::RemovePath);
+
+    for (const auto &tag : tags) {
+        const auto tagObj = tag.toObject();
+        m_content = m_content.replace(baseUrl + QStringLiteral("/tags/") + tagObj["name"].toString(),
+                                      QStringLiteral("hashtag:/") + tagObj["name"].toString(),
+                                      Qt::CaseInsensitive);
     }
 
     m_post_id = m_replyTargetId = obj["id"].toString();
@@ -113,7 +127,7 @@ Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
     m_link = QUrl(obj["url"].toString());
     m_pinned = obj["pinned"].toBool();
     m_visibility = stringToVisibility[obj["visibility"].toString()];
-    m_published_at = QDateTime::fromString(obj["created_at"].toString(), Qt::ISODate);
+    m_published_at = QDateTime::fromString(obj["created_at"].toString(), Qt::ISODate).toLocalTime();
     addAttachments(obj["media_attachments"].toArray());
     const QJsonArray mentions = obj["mentions"].toArray();
     if (obj.contains("card") && !obj["card"].toObject().empty()) {
@@ -125,12 +139,17 @@ Post::Post(AbstractAccount *account, QJsonObject obj, QObject *parent)
         m_mentions.push_back("@" + o["acct"].toString());
     }
 
+    if (obj.contains(QStringLiteral("poll")) && !obj[QStringLiteral("poll")].isNull()) {
+        m_poll = new Poll(obj[QStringLiteral("poll")].toObject());
+    }
+
     m_attachments_visible = !m_isSensitive;
 }
 
 Post::~Post()
 {
     qDeleteAll(m_attachments);
+    delete m_poll;
 }
 
 void Post::addAttachments(const QJsonArray &attachments)
@@ -164,6 +183,11 @@ void Post::setInReplyTo(const QString &inReplyTo)
     Q_EMIT inReplyToChanged();
 }
 
+int Post::repliesCount() const
+{
+    return m_repliesCount;
+}
+
 QString Post::inReplyTo() const
 {
     return m_replyTargetId;
@@ -231,6 +255,7 @@ static QMap<QString, Notification::Type> str_to_not_type = {
     {"follow", Notification::Type::Follow},
     {"mention", Notification::Type::Mention},
     {"reblog", Notification::Type::Repeat},
+    {"update", Notification::Type::Update},
 };
 
 Notification::Notification(AbstractAccount *account, const QJsonObject &obj, QObject *parent)
@@ -435,3 +460,19 @@ std::shared_ptr<Identity> Post::repeatIdentity() const
 {
     return m_repeatIdentity;
 }
+
+Poll *Post::poll() const
+{
+    return m_poll;
+}
+
+void Post::setPoll(Poll *poll)
+{
+    m_poll = poll;
+    Q_EMIT pollChanged();
+}
+
+QString Post::postId() const
+{
+    return m_post_id;
+}
