@@ -13,10 +13,11 @@ class ThreadModel : public TimelineModel
     Q_PROPERTY(QString postId READ postId WRITE setPostId NOTIFY postIdChanged)
 
 public:
-    ThreadModel(AccountManager *manager, const QString &postId, QObject *parent = nullptr);
+    ThreadModel(const QString &postId, QObject *parent = nullptr);
 
     QString postId() const;
     void setPostId(const QString &postId);
+    QVariant data(const QModelIndex &index, int role) const override;
 
     QString displayName() const override;
     void fillTimeline(const QString &fromId = QString()) override;
@@ -27,4 +28,6 @@ Q_SIGNALS:
 
 private:
     QString m_postId;
+
+    friend class TimelineTest;
 };
